<?php

namespace Concrete\Package\AbShowHide\Block\AbShowHide;

use Concrete\Core\Editor\LinkAbstractor;

/**
 * ab_show_hide package for Concrete5
 * Copyright Copyright 2017-2018, Alex Borisov
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @author Alex Borisov <linuxoidoz@gmail.com>
 * @package Concrete\Package\ab_show_hide
 */

class Controller extends \Concrete\Core\Block\BlockController
{
    
    protected $btWrapperClass = 'ccm-ui';
    protected $btInterfaceWidth = "600";
    protected $btInterfaceHeight = "400";
    protected $btTable = 'btAbShowHide';
    protected $btDefaultSet = 'basic';
    
    public function getBlockTypeDescription() 
    {
        return t("Add Content Show/Hide block");
    }

    public function getBlockTypeName() 
    {
        return t("Content Show/Hide");
    }

    public function getBlockUID($b = null) {
        if ($b == null) return null;
        $proxyBlock = $b->getProxyBlock();
        return $proxyBlock? $proxyBlock->getBlockID() : $b->bID;
    }
    
    public function on_start() {
        $this->set('app', $this->app);
    }
    
    public function registerViewAssets($outputContent = '')
    {
        if($this->popup) {
            $this->requireAsset('core/lightbox');
        }
        $this->requireAsset('javascript', 'jquery');
    }
    
    public function view() 
    {
        $this->set('text_show', LinkAbstractor::translateFrom($this->text_show));
        $this->set('text_hide', LinkAbstractor::translateFrom($this->text_hide));
    }

    public function edit()
    {
        $this->set('text_show', LinkAbstractor::translateFrom($this->text_show));
        $this->set('text_hide', LinkAbstractor::translateFrom($this->text_hide));
    }
    
    public function save($args) 
    {
        $args['text_show'] = LinkAbstractor::translateTo($args['text_show']);
        $args['text_hide'] = LinkAbstractor::translateTo($args['text_hide']);
        $args['btn_text'] = isset($args['btn_text']) ? $args['btn_text'] : t('show / hide');
        $args['popup'] = isset($args['popup']) ? 1 : 0;
        parent::save($args);
    }

    public function getTextShow()
    {
        return LinkAbstractor::translateFromEditMode($this->text_show);
    }

    public function getTextHide()
    {
        return LinkAbstractor::translateFromEditMode($this->text_hide);
    }
     
}
